==> spectrochempy-0.1.17.tar.gz: spectrochempy-0.1.17/spectrochempy/core/processors/interpolate.py <==
# -*- coding: utf-8 -*-
#
# ======================================================================================================================
# Copyright (©) 2015-2020 LCS
# Laboratoire Catalyse et Spectrochimie, Caen, France.
# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
# See full LICENSE agreement in the root directory
# ======================================================================================================================

"""
This module defines functions related to interpolations

"""

__all__ = ['interpolate']

__dataset_methods__ = __all__

# ----------------------------------------------------------------------------------------------------------------------
# third party imports
# ----------------------------------------------------------------------------------------------------------------------

import scipy.interpolate
import numpy as np

# ----------------------------------------------------------------------------------------------------------------------
# localimports
# ----------------------------------------------------------------------------------------------------------------------

from ...utils import NOMASK, MASKED, UnitsCompatibilityError
from spectrochempy.extern.orderedset import OrderedSet
from spectrochempy.core import warning_, error_

# ............................................................................
def interpolate(dataset, axis=0, size=None):
    #TODO: a simple interpolator of the data (either to reduce
    #      or increase number of points in every dimension)
    raise NotImplementedError('Not yet implemented')

==> spectrochempy-0.1.20.tar.gz: spectrochempy-0.1.20/spectrochempy/core/processors/interpolate.py <==
# -*- coding: utf-8 -*-
#
# ======================================================================================================================
# Copyright (©) 2015-2020 LCS
# Laboratoire Catalyse et Spectrochimie, Caen, France.
# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
# See full LICENSE agreement in the root directory
# ======================================================================================================================

"""
This module defines functions related to interpolations

"""

__all__ = ['interpolate']

__dataset_methods__ = __all__

# ----------------------------------------------------------------------------------------------------------------------
# third party imports
# ----------------------------------------------------------------------------------------------------------------------

# import scipy.interpolate
# import numpy as np

# ----------------------------------------------------------------------------------------------------------------------
# local imports
# ----------------------------------------------------------------------------------------------------------------------

# from ...utils import NOMASK, MASKED, UnitsCompatibilityError
# from spectrochempy.extern.orderedset import OrderedSet
# from spectrochempy.core import warning_, error_


# ............................................................................
def interpolate(dataset, axis=0, size=None):
    # TODO: a simple interpolator of the data (either to reduce
    #      or increase number of points in every dimension)
    raise NotImplementedError('Not yet implemented')
